@@ -49,6 +49,14 @@ states = {
 
 ERROR_TIMEOUT = "Timeout while updating"
 INFO_LOOP_RUNNING = "Event loop already running, not creating new one."
+UPDATE_TRIGGERS = [
+    "config_version",
+    "claims_version",
+    "override_version",
+    "schedule_version",
+    "schedule_plan_version",
+    "limit_version",
+]
 
 
 class OpenEVSE:
@@ -141,6 +149,7 @@ class OpenEVSE:
 
     async def update(self) -> None:
         """Update the values."""
+        # TODO: add addiontal endpoints to update
         urls = [f"{self.url}config"]
 
         if not self._ws_listening:
@@ -233,9 +242,11 @@ class OpenEVSE:
 
         elif msgtype == "data":
             _LOGGER.debug("Websocket data: %s", data)
-            if "wh" in data.keys():
+            keys = data.keys()
+            if "wh" in keys:
                 data["watthour"] = data.pop("wh")
-            elif "config_version" in data.keys():
+            # TODO: update specific endpoints based on _version prefix
+            if any(key in keys for key in UPDATE_TRIGGERS):
                 self.update()
             self._status.update(data)
 
@@ -412,6 +423,25 @@ class OpenEVSE:
             response, msg = await self.send_command(command)
             _LOGGER.debug("Set current response: %s", msg)
 
+    async def set_service_level(self, level: int = 2) -> None:
+        """Set the service level of the EVSE."""
+        if not isinstance(level, int) or not 0 <= level <= 2:
+            _LOGGER.error("Invalid service level: %s", level)
+            raise ValueError
+
+        url = f"{self.url}config"
+        data = {"service": level}
+
+        _LOGGER.debug("Set service level to: %s", level)
+        response = await self.process_request(
+            url=url, method="post", data=data
+        )  # noqa: E501
+        _LOGGER.debug("service response: %s", response)
+        result = response["msg"]
+        if result not in ["done", "no change"]:
+            _LOGGER.error("Problem issuing command: %s", response["msg"])
+            raise UnknownError
+
     # Restart OpenEVSE WiFi
     async def restart_wifi(self) -> None:
         """Restart OpenEVSE WiFi module."""
@@ -689,6 +719,8 @@ class OpenEVSE:
     def usage_total(self) -> float:
         """Return the total energy usage in Wh."""
         assert self._status is not None
+        if "total_energy" in self._status:
+            return self._status["total_energy"]
         return self._status["watthour"]
 
     @property
@@ -751,8 +783,50 @@ class OpenEVSE:
         Return the energy usage in Wh.
         """
         assert self._status is not None
+        if "session_energy" in self._status:
+            return self._status["session_energy"]
         return float(round(self._status["wattsec"] / 3600, 2))
 
+    @property
+    def total_day(self) -> float | None:
+        """Get the total day energy usage."""
+        assert self._status is not None
+        if "total_day" in self._status:
+            return self._status["total_day"]
+        return None
+
+    @property
+    def total_week(self) -> float | None:
+        """Get the total week energy usage."""
+        assert self._status is not None
+        if "total_week" in self._status:
+            return self._status["total_week"]
+        return None
+
+    @property
+    def total_month(self) -> float | None:
+        """Get the total week energy usage."""
+        assert self._status is not None
+        if "total_month" in self._status:
+            return self._status["total_month"]
+        return None
+
+    @property
+    def total_year(self) -> float | None:
+        """Get the total year energy usage."""
+        assert self._status is not None
+        if "total_year" in self._status:
+            return self._status["total_year"]
+        return None
+
+    @property
+    def has_limit(self) -> bool | None:
+        """Return if a limit has been set."""
+        assert self._status is not None
+        if "has_limit" in self._status:
+            return self._status["has_limit"]
+        return None
+
     @property
     def protocol_version(self) -> str | None:
         """Return the protocol version."""
